from readyResults import readyReport as reportAxial
from readyResults import graphLateral as reportLateral
from runAbaqus import runCommand as axial
from runAbaqus import runLateralModel as lateral
import numpy as np
import os
import time

tic = time.perf_counter()

p1 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\"

# The models
c0 = 'ModelS0C'
t0 = 'ModelS0T'
c90 = 'ModelS90C'
t90 = 'ModelS90T'
l0 = 'Lateral0'
l90 = 'Lateral90'


# Used to check if the .rpt file exists. Must only be run before a series of simulations, not for each individual job
def delete(filename, modelAbaqus):
    if modelAbaqus[0] == 'M':
        if os.path.isfile(p1 + filename + '.rpt'):
            os.remove(p1 + filename + '.rpt')
    if modelAbaqus[0] == 'L':
        if os.path.isfile(p1 + filename + '.rpt'):
            os.remove(p1 + filename + '.rpt')
    else: print("Model not recongized.")

# Standard function to run a model
def runAxial(modelAbaqus, modifier, embeddedLength, stiffness, redInt=False, noGUI=True):
    filename = 'rewrd'
    modelSpec = str(modelAbaqus[-1]) + "." + str(modelAbaqus[6]) + "." + str(embeddedLength)
    axial(filename, modelAbaqus, modifier, embeddedLength, stiffness, redInt, noGUI)
    reportAxial(filename, modelSpec, stiffness, modifier)
    delete(filename, modelAbaqus)

def runLateral(modelAbaqus, modifier, stiffness, redInt=False, noGUI=True):
    filename = "lojkerrewegere2"
    modelSpec = str(modelAbaqus)
    print("Running file: " + filename)
    lateral(filename, modelAbaqus, modifier, stiffness, redInt)
    print("Reporting stuff...")
    reportLateral(filename, modelSpec, modifier, stiffness)
    delete(filename, modelAbaqus)
    print("File deleted...")

def meshSensitivityStudy():
    for i in range(4):
        runAxial(t0, 650, (i+1)*110, 50, True)
        runAxial(c0, 650, (i+1)*110, 50, True)
        runAxial(t90, 650, (i+1)*110, 50, True)
        runAxial(c90, 650, (i+1)*110, 50, True)

def shearModulusStudy():
    for i in range(20):
        runAxial(c0, 50*(i+1), 110, 90)
        runAxial(c0, 50*(i+1), 220, 90)
        runAxial(c0, 50*(i+1), 330, 90)
        runAxial(c0, 50*(i+1), 440, 90)
        
def standardStudy(redInt):
    for i in range(4):
        runAxial(t0, 650, (i+1)*110, 90, redInt)
        runAxial(c0, 650, (i+1)*110, 90, redInt)
        runAxial(t90, 650, (i+1)*110, 90, redInt)
        runAxial(c90, 650, (i+1)*110, 90, redInt)

def shearModulusStudy():
    for i in range(20):
        runAxial(t0, 50*(i+1), 110, 10)
        runAxial(t0, 50*(i+1), 220, 10)
        runAxial(t0, 50*(i+1), 330, 10)
        runAxial(t0, 50*(i+1), 440, 10)
    for j in range(20):
        runAxial(c0, 50*(j+1), 110, 10)
        runAxial(c0, 50*(j+1), 220, 10)
        runAxial(c0, 50*(j+1), 330, 10)
        runAxial(c0, 50*(j+1), 440, 10)
    for k in range(20):
        runAxial(t90, 50*(k+1), 110, 10)
        runAxial(t90, 50*(k+1), 220, 10)
        runAxial(t90, 50*(k+1), 330, 10)
        runAxial(t90, 50*(k+1), 440, 10)
    for l in range(20):
        runAxial(c90, 50*(l+1), 110, 10)
        runAxial(c90, 50*(l+1), 220, 10)
        runAxial(c90, 50*(l+1), 330, 10)
        runAxial(c90, 50*(l+1), 440, 10)

def cohesiveStiffnessStudy():
    for i in range(20):
        runAxial(t0, 650, 110, 5*(i+1))
        runAxial(t0, 650, 220, 5*(i+1))
        runAxial(t0, 650, 330, 5*(i+1))
        runAxial(t0, 650, 440, 5*(i+1))
    for j in range(20):
        runAxial(c0, 650, 110, 5*(j+1))
        runAxial(c0, 650, 220, 5*(j+1))
        runAxial(c0, 650, 330, 5*(j+1))
        runAxial(c0, 650, 440, 5*(j+1))
    for k in range(20):
        runAxial(t90, 650, 110, 5*(k+1))
        runAxial(t90, 650, 220, 5*(k+1))
        runAxial(t90, 650, 330, 5*(k+1))
        runAxial(t90, 650, 440, 5*(k+1))
    for l in range(20):
        runAxial(c90, 650, 110, 5*(l+1))
        runAxial(c90, 650, 220, 5*(l+1))
        runAxial(c90, 650, 330, 5*(l+1))
        runAxial(c90, 650, 440, 5*(l+1))

def bothStudy():
    for i in range(20):
        runAxial(t0, 50*(i+1), 110, 5*(i+1))
        runAxial(t0, 50*(i+1), 220, 5*(i+1))
        runAxial(t0, 50*(i+1), 330, 5*(i+1))
        runAxial(t0, 50*(i+1), 440, 5*(i+1))
    for j in range(20):
        runAxial(c0, 50*(j+1), 110, 5*(j+1))
        runAxial(c0, 50*(j+1), 220, 5*(j+1))
        runAxial(c0, 50*(j+1), 330, 5*(j+1))
        runAxial(c0, 50*(j+1), 440, 5*(j+1))
    for k in range(20):
        runAxial(t90, 50*(k+1), 110, 5*(k+1))
        runAxial(t90, 50*(k+1), 220, 5*(k+1))
        runAxial(t90, 50*(k+1), 330, 5*(k+1))
        runAxial(t90, 50*(k+1), 440, 5*(k+1))
    for l in range(20):
        runAxial(c90, 50*(l+1), 110, 5*(l+1))
        runAxial(c90, 50*(l+1), 220, 5*(l+1))
        runAxial(c90, 50*(l+1), 330, 5*(l+1))
        runAxial(c90, 50*(l+1), 440, 5*(l+1))

def EStudy():
    for i in range(10):
        runAxial(t0, (i+1)*5, 110, 10)
        runAxial(t0, (i+1)*5, 2*110, 10)
        runAxial(t0, (i+1)*5, 3*110, 10)
        runAxial(t0, (i+1)*5, 4*110, 10)

runAxial(t0, 2, 440, 16.5)
runAxial(t90, 2, 440, 140)


toc = time.perf_counter()
print(f"The Abaqus job finished in {(toc - tic)/60:0.2f} minutes.")

