
from abaqus import *
from abaqusConstants import *
import __main__
import section
import regionToolset
import displayGroupMdbToolset as dgm
import part
import material
import assembly
import step
import interaction
import load
import mesh
import optimization
import job
import sketch
import visualization
import xyPlot
import displayGroupOdbToolset as dgo
import connectorBehavior
import argparse
import sys

# Engineering constants for GL30c
E1 = 1000
E2 = 30
E3 = E2
Nu12 = 0
Nu13 = 0
Nu23 = 0
G12 = 650
G13 = G12
G23 = 30

def openJob(): openMdb(pathName='C:/temp/AlisaExperimentDBFail.cae')

def specifyCoefficients(modelAbaqus, modifier, embeddedLength, stiffness, redInt):

    a = mdb.models[modelAbaqus].rootAssembly
    session.viewports['Viewport: 1'].setValues(displayedObject=a)
    session.viewports['Viewport: 1'].assemblyDisplay.setValues(interactions=ON, 
        constraints=ON, connectors=ON, engineeringFeatures=ON, 
        optimizationTasks=OFF, geometricRestrictions=OFF, stopConditions=OFF)
    mdb.models[modelAbaqus].interactionProperties['Cohesive'].damage.setValues(
        evolTable=((modifier, ), ))
    mdb.models[modelAbaqus].interactionProperties['Cohesive'].damage.setValues(
        initTable=((100000000.0, stiffness, stiffness), ))

    
    # Specify material coefficients for fictitious material
    mdb.models[modelAbaqus].materials['FictitiousMaterial'].Elastic(type=ENGINEERING_CONSTANTS,
    table=((E1, E2, E3, Nu12, Nu13, Nu23, G12, G13, G23),) )
    

    # Specify embedded length (default = 110)
    a = mdb.models[modelAbaqus].rootAssembly
    a.translate(instanceList=('RodCoreOuter-1', ), vector=(0.0, 0.0, -(embeddedLength-110)))
    a = mdb.models[modelAbaqus].rootAssembly
    a.translate(instanceList=('RodCoreInner-1', ), vector=(0.0, 0.0, -(embeddedLength-110)))

    # Specify cohesive zone stiffness property
    mdb.models[modelAbaqus].interactionProperties['Cohesive'].cohesiveBehavior.setValues(table=((0.1, 90, 90), ))
    
    # Specify reduced integration for mesh (default=OFF)
    if redInt=='True':
        elemType1 = mesh.ElemType(elemCode=C3D8R, elemLibrary=STANDARD, 
        secondOrderAccuracy=OFF, distortionControl=DEFAULT)
        elemType2 = mesh.ElemType(elemCode=C3D6, elemLibrary=STANDARD)
        elemType3 = mesh.ElemType(elemCode=C3D4, elemLibrary=STANDARD)
        p = mdb.models[modelAbaqus].parts['FictitiousPart']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#f ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, 
            elemType3))
        p = mdb.models[modelAbaqus].parts['RodCoreInner']
        session.viewports['Viewport: 1'].setValues(displayedObject=p)
        session.viewports['Viewport: 1'].view.fitView()
        elemType1 = mesh.ElemType(elemCode=C3D8R, elemLibrary=STANDARD, 
            secondOrderAccuracy=ON, distortionControl=DEFAULT)
        elemType2 = mesh.ElemType(elemCode=C3D6, elemLibrary=STANDARD)
        elemType3 = mesh.ElemType(elemCode=C3D4, elemLibrary=STANDARD)
        p = mdb.models[modelAbaqus].parts['RodCoreInner']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#ff ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, 
            elemType3))
        p = mdb.models[modelAbaqus].parts['RodCoreOuter']
        session.viewports['Viewport: 1'].setValues(displayedObject=p)
        session.viewports['Viewport: 1'].view.fitView()
        elemType1 = mesh.ElemType(elemCode=C3D8R, elemLibrary=STANDARD, 
            secondOrderAccuracy=OFF, distortionControl=DEFAULT)
        elemType2 = mesh.ElemType(elemCode=C3D6, elemLibrary=STANDARD)
        elemType3 = mesh.ElemType(elemCode=C3D4, elemLibrary=STANDARD)
        p = mdb.models[modelAbaqus].parts['RodCoreOuter']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#ff ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, 
            elemType3))
        p = mdb.models[modelAbaqus].parts['WoodBlockCoarse']
        session.viewports['Viewport: 1'].setValues(displayedObject=p)
        session.viewports['Viewport: 1'].view.fitView()
        elemType1 = mesh.ElemType(elemCode=C3D8R, elemLibrary=STANDARD, 
            secondOrderAccuracy=OFF, distortionControl=DEFAULT)
        elemType2 = mesh.ElemType(elemCode=C3D6, elemLibrary=STANDARD)
        elemType3 = mesh.ElemType(elemCode=C3D4, elemLibrary=STANDARD)
        p = mdb.models[modelAbaqus].parts['WoodBlockCoarse']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#ffffffff:2 #ff ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, 
            elemType3))
        p = mdb.models[modelAbaqus].parts['WoodBlockFine']
        session.viewports['Viewport: 1'].setValues(displayedObject=p)
        session.viewports['Viewport: 1'].view.fitView()
        elemType1 = mesh.ElemType(elemCode=C3D8R, elemLibrary=STANDARD, 
            secondOrderAccuracy=OFF, distortionControl=DEFAULT)
        elemType2 = mesh.ElemType(elemCode=C3D6, elemLibrary=STANDARD)
        elemType3 = mesh.ElemType(elemCode=C3D4, elemLibrary=STANDARD)
        p = mdb.models[modelAbaqus].parts['WoodBlockFine']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#f ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, 
            elemType3))
        a = mdb.models[modelAbaqus].rootAssembly
        a.regenerate()
        session.viewports['Viewport: 1'].setValues(displayedObject=a)
        session.viewports['Viewport: 1'].assemblyDisplay.setValues(
            optimizationTasks=OFF, geometricRestrictions=OFF, stopConditions=OFF)
        
    # Nonlinear geometry
    mdb.models[modelAbaqus].steps['Displacement'].setValues(nlgeom=OFF)
    print(redInt)
    

def runJob(filename, modelAbaqus):

    # Creating, submitting and waiting for completion of job
    mdb.Job(name=filename, model=modelAbaqus, description='', type=ANALYSIS, 
    atTime=None, waitMinutes=0, waitHours=0, queue=None, memory=90, 
    memoryUnits=PERCENTAGE, getMemoryFromAnalysis=True, 
    explicitPrecision=SINGLE, nodalOutputPrecision=SINGLE, echoPrint=OFF, 
    modelPrint=OFF, contactPrint=OFF, historyPrint=OFF, userSubroutine='', 
    scratch='', resultsFormat=ODB, multiprocessingMode=DEFAULT, numCpus=1, 
    numGPUs=0)
    mdb.jobs[filename].submit(consistencyChecking=OFF)
    mdb.jobs[filename].waitForCompletion()      

def openResults(filename, modelAbaqus):
    o3 = session.openOdb(name='C:/Users/Johannes/'+ filename +'.odb')
    session.viewports['Viewport: 1'].setValues(displayedObject=o3)
    session.viewports['Viewport: 1'].makeCurrent()
    session.linkedViewportCommands.setValues(_highlightLinkedViewports=False)
    odb = session.odbs['C:/Users/Johannes/'+ filename +'.odb']

    # Kind of a black box and not very elegant, but opens results, creates XY data, 
    # prints the data to a .rpt file in a specified folder and deletes the data to 
    # avoid conflicts with a later simulation

    #session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('CF', NODAL, ((COMPONENT, 'CF3'), )), ), nodeSets=("RODCOREINNER-1.LOADREFERENCENODE", ))
    session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('RF', NODAL, ((COMPONENT, 'RF3'), )), ), nodeSets=("RODCOREINNER-1.LOADREFERENCENODE", ))
    odb = session.odbs['C:/Users/Johannes/'+ filename +'.odb']
    session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('U', 
            NODAL, ((COMPONENT, 'U3'), )), ), nodeSets=("MEASUREPOINTCH1", 
            "MEASUREPOINTCH2", "MEASUREPOINTLD1", "MEASUREPOINTLD2", 
            "PLATEMEASUREPOINTLD1", "PLATEMEASUREPOINTLD2", "WOODMEASUREPOINTCH1", 
            "WOODMEASUREPOINTCH2", ))
    #x0 = session.xyDataObjects['CF:CF3 PI: RODCOREINNER-1 N: 12']
    x0 = session.xyDataObjects['RF:RF3 PI: RODCOREINNER-1 N: 12']
    x1 = session.xyDataObjects['U:U3 PI: MEASUREPLATE-1 N: 23']
    x2 = session.xyDataObjects['U:U3 PI: MEASUREPLATE-2 N: 23']
    x3 = session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 2']
    x4 = session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 7']
    x5 = session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 26']
    x6 = session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 31']
    x7 = session.xyDataObjects['U:U3 PI: WOODBLOCKCOARSE-1 N: 112']
    x8 = session.xyDataObjects['U:U3 PI: WOODBLOCKCOARSE-1 N: 116']
    session.writeXYReport(fileName='C:/Users/Johannes/Documents/Masteroppgave/Calibration/' + filename + '.rpt', 
        xyData=(x0, x1, x2, x3, x4, x5, x6, x7, x8), appendMode=OFF)
    del session.xyDataObjects['CF:CF3 PI: RODCOREINNER-1 N: 12']
    del session.xyDataObjects['U:U3 PI: MEASUREPLATE-1 N: 23']
    del session.xyDataObjects['U:U3 PI: MEASUREPLATE-2 N: 23']
    del session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 2']
    del session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 7']
    del session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 26']
    del session.xyDataObjects['U:U3 PI: MEASURINGDEVICE-1 N: 31']
    del session.xyDataObjects['U:U3 PI: WOODBLOCKCOARSE-1 N: 112']
    del session.xyDataObjects['U:U3 PI: WOODBLOCKCOARSE-1 N: 116']

def quickJob(filename, modelAbaqus, modifier, embeddedLength, stiffness, redInt):
    openJob()
    specifyCoefficients(modelAbaqus, modifier, embeddedLength, stiffness, redInt)
    runJob(filename, modelAbaqus)
    openResults(filename, modelAbaqus)

# Arguments passed through runAbaqus.py 
argFilename = str(sys.argv[-6])
argModelAbaqus = str(sys.argv[-5])
argModifier = float(sys.argv[-4])
argEmbeddedLength = float(sys.argv[-3])
argStiffness = float(sys.argv[-2])
argRedInt = str(sys.argv[-1])


# Running the job
quickJob(argFilename, argModelAbaqus, argModifier, argEmbeddedLength, argStiffness, argRedInt)
