
from abaqus import *
from abaqusConstants import *
import __main__
import section
import regionToolset
import displayGroupMdbToolset as dgm
import part
import material
import assembly
import step
import interaction
import load
import mesh
import optimization
import job
import sketch
import visualization
import xyPlot
import displayGroupOdbToolset as dgo
import connectorBehavior
import argparse
import sys

# Engineering constants for GL30c
E1 = 13000
E2 = 300
E3 = E2
Nu12 = 0
Nu13 = 0
Nu23 = 0
G12 = 650
G13 = G12
G23 = 65

def openJob(): openMdb(pathName='C:/temp/AlisaExperimentDB.cae')

def specifyCoefficients(modelAbaqus, modifier, stiffness, redInt):

    # Specify material coefficients for fictitious material
    mdb.models[modelAbaqus].materials['FictitiousMaterial'].Elastic(type=ENGINEERING_CONSTANTS,
    table=((modifier, E2,E3, Nu12, Nu13, Nu23, G12, G13, G23),) )

    # Specify cohesive zone stiffness property
    mdb.models[modelAbaqus].interactionProperties['Cohesive'].cohesiveBehavior.setValues(table=((stiffness, 90, 90), ))

    # Specify reduced integration for mesh (default=OFF)
    if redInt:
        elemType1 = mesh.ElemType(elemCode=C3D8R, elemLibrary=STANDARD, secondOrderAccuracy=OFF, distortionControl=DEFAULT)
        elemType2 = mesh.ElemType(elemCode=C3D6, elemLibrary=STANDARD)
        elemType3 = mesh.ElemType(elemCode=C3D4, elemLibrary=STANDARD)
        p = mdb.models[modelAbaqus].parts['FictitiousPart']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#f ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, elemType3))
        p = mdb.models[modelAbaqus].parts['Rod']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#f ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, elemType3))
        p = mdb.models[modelAbaqus].parts['WoodBlockCoarse']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#f ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, elemType3))
        p = mdb.models[modelAbaqus].parts['WoodBlockFine']
        c = p.cells
        cells = c.getSequenceFromMask(mask=('[#f ]', ), )
        pickedRegions =(cells, )
        p.setElementType(regions=pickedRegions, elemTypes=(elemType1, elemType2, elemType3))
    
    # Nonlinear geometry
    mdb.models[modelAbaqus].steps['Displacement'].setValues(nlgeom=OFF)

def runJob(filename, modelAbaqus):

    # Creating, submitting and waiting for completion of job
    mdb.Job(name=filename, model=modelAbaqus, description='', type=ANALYSIS, 
    atTime=None, waitMinutes=0, waitHours=0, queue=None, memory=90, 
    memoryUnits=PERCENTAGE, getMemoryFromAnalysis=True, 
    explicitPrecision=SINGLE, nodalOutputPrecision=SINGLE, echoPrint=OFF, 
    modelPrint=OFF, contactPrint=OFF, historyPrint=OFF, userSubroutine='', 
    scratch='', resultsFormat=ODB, multiprocessingMode=DEFAULT, numCpus=1, 
    numGPUs=0)
    mdb.jobs[filename].submit(consistencyChecking=OFF)
    mdb.jobs[filename].waitForCompletion()    

def openResults(filename, modelAbaqus):
    if modelAbaqus == 'Lateral0':
        o3 = session.openOdb(name='C:/Users/Johannes/'+ filename +'.odb')
        session.viewports['Viewport: 1'].setValues(displayedObject=o3)
        session.viewports['Viewport: 1'].makeCurrent()
        session.linkedViewportCommands.setValues(_highlightLinkedViewports=False)
        odb = session.odbs['C:/Users/Johannes/'+ filename +'.odb']
        session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('U', NODAL, ((COMPONENT, 'U2'), )), ), nodeSets=("MEASUREPOINTSIDES", "ROD-1.MEASUREPOINTROD", ))
        session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('CF', NODAL, ((COMPONENT, 'CF2'), )), ), nodeSets=("ROD-1.MEASUREPOINTROD", ))
        xy1 = session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 12']
        xy2 = session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 20']
        xy3 = avg((xy1, xy2))
        xy3.setValues(
            sourceDescription='avg ( ( "U:U2 PI: WOODBLOCKCOARSE-1 N: 12", "U:U2 PI: WOODBLOCKCOARSE-1 N: 20" ) )')
        tmpName = xy3.name
        session.xyDataObjects.changeKey(tmpName, 'DisplacementSides')
        session.xyDataObjects.changeKey(fromName='CF:CF2 PI: ROD-1 N: 15', 
            toName='ForceNodeRod')
        session.xyDataObjects.changeKey(fromName='U:U2 PI: ROD-1 N: 15', 
            toName='DisplacementRod')
        x0 = session.xyDataObjects['DisplacementRod']
        x1 = session.xyDataObjects['DisplacementSides']
        x2 = session.xyDataObjects['ForceNodeRod']
        session.writeXYReport(
            fileName='C:/Users/Johannes/Documents/Masteroppgave/Calibration/' + filename + '.rpt', 
            xyData=(x0, x1, x2))
        del session.xyDataObjects['DisplacementRod']
        del session.xyDataObjects['DisplacementSides']
        del session.xyDataObjects['ForceNodeRod']
        del session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 12']
        del session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 20']

    else:
        o3 = session.openOdb(name='C:/Users/Johannes/'+ filename +'.odb')
        session.viewports['Viewport: 1'].setValues(displayedObject=o3)
        session.viewports['Viewport: 1'].makeCurrent()
        session.linkedViewportCommands.setValues(_highlightLinkedViewports=False)
        odb = session.odbs['C:/Users/Johannes/'+ filename +'.odb']
        session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('U', NODAL, ((COMPONENT, 'U2'), )), ), nodeSets=("SIDES", "ROD-1.RODNODE", ))
        session.xyDataListFromField(odb=odb, outputPosition=NODAL, variable=(('CF', NODAL, ((COMPONENT, 'CF2'), )), ), nodeSets=("ROD-1.RODNODE", ))
        xy1 = session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 375']
        xy2 = session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 436']
        xy3 = avg((xy1, xy2))
        xy3.setValues(sourceDescription='avg ( ( "U:U2 PI: WOODBLOCKCOARSE-1 N: 375", "U:U2 PI: WOODBLOCKCOARSE-1 N: 436" ) )')
        tmpName = xy3.name
        session.xyDataObjects.changeKey(tmpName, 'DisplacementSides')
        session.xyDataObjects.changeKey(fromName='CF:CF2 PI: ROD-1 N: 15', toName='ForceNodeRod')
        session.xyDataObjects.changeKey(fromName='U:U2 PI: ROD-1 N: 15', toName='DisplacementRod')
        x0 = session.xyDataObjects['DisplacementRod']
        x1 = session.xyDataObjects['DisplacementSides']
        x2 = session.xyDataObjects['ForceNodeRod']
        session.writeXYReport(fileName='C:/Users/Johannes/Documents/Masteroppgave/Calibration/' + filename + '.rpt', xyData=(x0, x1, x2))
        del session.xyDataObjects['DisplacementRod']
        del session.xyDataObjects['DisplacementSides']
        del session.xyDataObjects['ForceNodeRod']
        del session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 375']
        del session.xyDataObjects['U:U2 PI: WOODBLOCKCOARSE-1 N: 436']



def quickJob(filename, modelAbaqus, modifier, stiffness, redInt):
    openJob()
    specifyCoefficients(modelAbaqus, modifier, stiffness, redInt)
    runJob(filename, modelAbaqus)
    openResults(filename, modelAbaqus)

# Arguments passed through runAbaqus.py 
argFilename = str(sys.argv[-5])
argModelAbaqus = str(sys.argv[-4])
argModifier = float(sys.argv[-3])
argStiffness = float(sys.argv[-2])
argRedInt = bool(sys.argv[-1])

# Running the job
quickJob(argFilename, argModelAbaqus, argModifier, argStiffness, argRedInt)