import matplotlib as mpl
import matplotlib.pyplot as plt
import numpy as np
import csv
import os
import sys

p1 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\"
p2 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\Reports\\"

# Removes irrelevant rows
def removeRows(filename):
    rows = []
    f = open(p1 + filename + ".rpt")
    for line in f: 
        line = line.split()
        if len(line) > 0:
            try:
                if float(line[0])!=0.0:
                    rows.append(line)
            except: pass
    f.close()
    return rows
"""
# Calculates distances and stiffnesses and makes ready for .csv file
def doCalculations(rows):
    new_list = []
    for line in rows:
        row = []
        # Step
        #row.append(float(line[0]))
        # Actual force
        actual_force = round(float(line[1])*73, 4)
        #row.append(actual_force)
        # LD1
        ld1 = float(line[4])-float(line[3])
        ld1 = round(ld1, 4)
        #row.append(ld1)
        # LD2
        ld2 = float(line[6])-float(line[2])
        ld2 = round(ld2,4)
        #row.append(ld2)
        # CH1
        ch1 = float(line[5])-float(line[8])
        ch1 = round(ch1,4)
        #row.append(ch1)
        # CH2
        ch2 = float(line[7])-float(line[9])
        ch2 = round(ch2,4)
        #row.append(ch2)
        # K_LD
        ldAvg = 0.5*(ld1+ld2)
        kld = 0.001*actual_force/ldAvg
        kld = round(kld, 2)
        row.append(kld)
        # K_CH
        chAvg = 0.5*(ch1+ch2)
        kch = 0.001*actual_force/chAvg
        kch = round(kch, 2)
        row.append(kch)
        # Append entire row to list
        new_list.append(row)
    return new_list"""

def doCalculations(rows):
    new_list = []
    for line in rows:
        row = []
        # Step
        #row.append(float(line[0]))
        # Actual force
        actual_force = round(float(line[1])*73, 4)
        row.append(actual_force)
        # LD1
        ld1 = float(line[4])-float(line[3])
        ld1 = round(ld1, 4)
        #row.append(ld1)
        # LD2
        ld2 = float(line[6])-float(line[2])
        ld2 = round(ld2,4)
        #row.append(ld2)
        # CH1
        ch1 = float(line[5])-float(line[8])
        ch1 = round(ch1,4)
        #row.append(ch1)
        # CH2
        ch2 = float(line[7])-float(line[9])
        ch2 = round(ch2,4)
        #row.append(ch2)
        # K_LD
        ldAvg = 0.5*(ld1+ld2)
        kld = ldAvg
        kld = round(kld, 2)
        row.append(kld)
        # K_CH
        chAvg = 0.5*(ch1+ch2)
        kch = chAvg
        kch = round(kch, 2)
        row.append(kch)
        # Append entire row to list
        new_list.append(row)
    return new_list

# Ties it all together
def readyReport(filename, modelSpec, stiffness, modifier):

    p2 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\Mesh\\"

    # Open .rpt file exported from Abaqus and clean it up
    step1 = removeRows(filename)
    
    # Performs simple calcs incl. stiffness for CH and LD
    step2 = doCalculations(step1)

    # Write a new .csv file
    c = open(p2 + modelSpec + '.csv', 'a', newline='')
    writer = csv.writer(c)   

    # Add results to file and add LD & CH to list
    ld = []
    ch = []
    for line in step2: 
    #    writer.writerow(line)
        ld.append(line[-2])
        ch.append(line[-1])
        writer.writerow([line[-3], line[-2], line[-1]])
    #writer.writerow([str(sum(ld)/len(ld)), str(sum(ch)/len(ch)), str(stiffness), str(modifier)])

    c.close()

def openFile(filename):

    p2 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\Reports\\"
    c = open(p2+filename+'.csv', 'r')
    reader = csv.reader(c)
    for line in reader:
        return line

# Main graph generator for comparing a result to "reference" values
def generateGraphs(path, expl):

    explanation = str(expl)

    x = ['5d', '10d', '15d', '20d']

    # LD, CH
    ref_c0 = [[124.2, 123.2, 120.8, 119.2], [108.2, 103.2, 102.8, 109.8]]
    ref_c90 = [[56.2, 68.6, 74.9, 83.7], [75.4, 69.2, 72.4, 83.4]]
    ref_t0 = [[138.7, 180.4, 180.9, 159.4], [123.3, 145.3, 145.4, 145.4]]
    ref_t90 = [[59, 87.70, 103.60, 102.70], [58.1, 78.6, 95.4, 91.8]]

    # This is where "my" stiffness values go 
    y_t0 = [[],[]]
    y_t90 = [[],[]]
    y_c0 = [[],[]]
    y_c90 = [[],[]]

    # Read all .csv files in directory 
    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(path+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_c0[0].append((round(float(line[0]),2)))
            y_c0[1].append((round(float(line[1]),2)))
        angle = 9
        c = open(path+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_c90[0].append((round(float(line[0]),2)))
            y_c90[1].append((round(float(line[1]),2)))
        angle = 0
        c = open(path+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t0[0].append((round(float(line[0]),2)))
            y_t0[1].append((round(float(line[1]),2)))
        angle = 9
        c = open(path+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t90[0].append((round(float(line[0]),2)))
            y_t90[1].append((round(float(line[1]),2)))

    # The "big 4" comparison plot
    plt.rc('font', size=12)
    plt.rc('legend', fontsize=10)    # legend fontsize
    fig, axs = plt.subplots(2, 2, figsize=(10, 6), sharex=True, sharey=True)

    axs[0,0].plot(x, y_t0[0], 'tab:green', label=r"$K_{LD,numerical}$")
    axs[0,0].plot(x, y_t0[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    axs[0,0].plot(x, ref_t0[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    axs[0,0].plot(x, ref_t0[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    axs[0,0].set_title("(a) "+r'$Tension, \alpha=0^o$')

    axs[0,1].plot(x, y_c0[0],'tab:red', label=r"$K_{LD,numerical}$")
    axs[0,1].plot(x, y_c0[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    axs[0,1].plot(x, ref_c0[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    axs[0,1].plot(x, ref_c0[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    axs[0,1].set_title("(b) "+r'$Compression, \alpha=0^o$')

    axs[1,0].plot(x, y_t90[0], 'tab:green',label=r"$K_{LD,numerical}$")
    axs[1,0].plot(x, y_t90[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    axs[1,0].plot(x, ref_t90[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    axs[1,0].plot(x, ref_t90[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    axs[1,0].set_title("(c) "+r'$Tension, \alpha=90^o$')

    axs[1,1].plot(x, y_c90[0],'tab:red', label=r"$K_{LD,numerical}$")
    axs[1,1].plot(x, y_c90[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    axs[1,1].plot(x, ref_c90[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    axs[1,1].plot(x, ref_c90[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    axs[1,1].set_title("(d) "+r'$Compression, \alpha=90^o$')

    for ax in axs.flat:
        ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
        ax.label_outer()
        ax.legend()

    plt.savefig(path+"\\"+explanation+"_All.png")

    # The individual plots
    plt.rc('font', size=18)
    plt.rc('legend', fontsize=16) 

    # Tension, 0 deg
    fig2, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_t0[0], 'tab:green', label=r"$K_{LD,numerical}$")
    ax.plot(x, y_t0[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    ax.plot(x, ref_t0[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    ax.plot(x, ref_t0[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    ax.set_title(r'$Tension, \alpha=0^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\"+explanation+"_t0.png")

    # Tension, 90 deg
    fig3, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_t90[0], 'tab:green',label=r"$K_{LD,numerical}$")
    ax.plot(x, y_t90[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    ax.plot(x, ref_t90[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    ax.plot(x, ref_t90[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    ax.set_title(r'$Tension, \alpha=90^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\"+explanation+"_t90.png")

    # Compression, 0 deg
    fig4, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_c0[0],'tab:red', label=r"$K_{LD,numerical}$")
    ax.plot(x, y_c0[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    ax.plot(x, ref_c0[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    ax.plot(x, ref_c0[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    ax.set_title(r'$Compression, \alpha=0^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\"+explanation+"_c0.png")

    # Compression, 90 deg
    fig5, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_c90[0],'tab:red', label=r"$K_{LD,numerical}$")
    ax.plot(x, y_c90[1], 'tab:orange', label=r"$K_{CH,numerical}$")
    ax.plot(x, ref_c90[0], 'tab:gray', linestyle='dashdot', label=r"$K_{LD,experimental}$")
    ax.plot(x, ref_c90[1], 'tab:brown', linestyle='dashdot', label=r"$K_{CH,experimental}$")
    ax.set_title(r'$Compression, \alpha=90^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\"+explanation+"_c90.png")
        

# Compares the average of LD and CH of two different models to average of reference values
def compareTwoModels(p1, p2):

    x = ['5d', '10d', '15d', '20d']

    # Average of Alisa LD and CH values
    avg_c0 = [116.2, 113.2, 111.8, 114.5]
    avg_c90 = [65.8, 68.9, 73.65, 83.55]
    avg_t0 = [131, 162.85, 163.15, 152.4]
    avg_t90 = [58.55, 83.15, 99.5, 97.25]

    # This is where "my" average stiffness values go 
    y_t0 = []
    y_t90 = []
    y_c0 = []
    y_c90 = []

    # Second round of stiffness values
    y_t0b = []
    y_t90b = []
    y_c0b = []
    y_c90b = []

    # Read all .csv files in first directory 
    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(p1+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_c0.append(0.5*(x1+x2))
        angle = 9
        c = open(p1+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_c90.append(0.5*(x1+x2))
        angle = 0
        c = open(p1+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_t0.append(0.5*(x1+x2))
        angle = 9
        c = open(p1+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_t90.append(0.5*(x1+x2))

    # Read all .csv files in second directory 
    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(p2+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_c90b.append(0.5*(x1+x2))
        angle = 9
        c = open(p2+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_c0b.append(0.5*(x1+x2))
        angle = 0
        c = open(p2+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_t0b.append(0.5*(x1+x2))
        angle = 9
        c = open(p2+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_t90b.append(0.5*(x1+x2))



    # The "big 4" comparison plot
    plt.rc('font', size=12)
    plt.rc('legend', fontsize=10)    # legend fontsize
    fig, axs = plt.subplots(2, 2, figsize=(10, 6), sharex=True, sharey=True)

    axs[0,0].plot(x, y_t0, 'tab:green', label=r"$K_{avg}$")
    axs[0,0].plot(x, y_t0b, 'tab:blue', label=r"$K_{avg}$")
    axs[0,0].plot(x, avg_t0, 'tab:gray', linestyle='dashdot', label=r"$K_{avg,exp}$")
    axs[0,0].set_title("(a) "+r'$Tension, \alpha=0^o$')

    axs[0,1].plot(x, y_c0,'tab:red', label=r"$K_{avg}$")
    axs[0,1].plot(x, y_c0b, 'tab:blue', label=r"$K_{avg}$")
    axs[0,1].plot(x, avg_c0, 'tab:gray', linestyle='dashdot', label=r"$K_{avg,exp}$")
    axs[0,1].set_title("(b) "+r'$Compression, \alpha=0^o$')

    axs[1,0].plot(x, y_t90, 'tab:green',label=r"$K_{avg}$")
    axs[1,0].plot(x, y_t90b, 'tab:orange', label=r"$K_{avg}$")
    axs[1,0].plot(x, avg_t90, 'tab:gray', linestyle='dashdot', label=r"$K_{avg,exp}$")
    axs[1,0].set_title("(c) "+r'$Tension, \alpha=90^o$')

    axs[1,1].plot(x, y_c90,'tab:red', label=r"$K_{avg}$")
    axs[1,1].plot(x, y_c90b, 'tab:orange', label=r"$K_{avg}$")
    axs[1,1].plot(x, avg_c90, 'tab:brown', linestyle='dashdot', label=r"$K_{avg,exp}$")
    axs[1,1].set_title("(d) "+r'$Compression, \alpha=90^o$')

    for ax in axs.flat:
        ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
        ax.label_outer()
        ax.legend()

    plt.savefig(p1+"\\compareModels.png")
    
    # The individual plots
    plt.rc('font', size=18)
    plt.rc('legend', fontsize=16) 

    # Tension, 0 deg
    fig2, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_t0, 'tab:green', label=r"$K_{avg}$")
    ax.plot(x, y_t0b, 'tab:orange', label=r"$K_{avg}$")
    ax.plot(x, avg_t0, 'tab:brown', linestyle='dashdot', label=r"$K_{avg,exp}$")
    ax.set_title(r'$Tension, \alpha=0^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(p1+"\\t0comparison.png")

    # Tension, 90 deg
    fig3, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_t90, 'tab:green', label=r"$K_{avg}$")
    ax.plot(x, y_t90b, 'tab:orange', label=r"$K_{avg}$")
    ax.plot(x, avg_t90, 'tab:brown', linestyle='dashdot', label=r"$K_{avg,exp}$")
    ax.set_title(r'$Tension, \alpha=90^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(p1+"\\t90comparison.png")

    # Compression, 0 deg
    fig4, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_c0, 'tab:green', label=r"$K_{avg}$")
    ax.plot(x, y_c0b, 'tab:orange', label=r"$K_{avg}$")
    ax.plot(x, avg_c0, 'tab:brown', linestyle='dashdot', label=r"$K_{avg,exp}$")
    ax.set_title(r'$Compression, \alpha=0^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(p1+"\\c0comparison.png")

    # Compression, 90 deg
    fig5, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_c90, 'tab:green', label=r"$K_{avg}$")
    ax.plot(x, y_c90b, 'tab:orange', label=r"$K_{avg}$")
    ax.plot(x, avg_c90, 'tab:brown', linestyle='dashdot', label=r"$K_{avg,exp}$")
    ax.set_title(r'$Compression, \alpha=90^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(p1+"\\c90comparison.png")

# For comparing many many plots 
def compareStudy():

    x = ['5d', '10d', '15d', '20d']
    ref_t0 = [138.7, 180.4, 180.9, 159.4]
    avg_t0 = [131, 162.85, 163.15, 152.4]
    y_t0 = []
    y = []
    y_mod = []
    y_sti = []

    p2 = r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\Full_Integration\ParameterStudies\OldMesh\\"

    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(p2+'T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t0.append((round(float(line[0]),2)))
            
    splits = np.array_split(y_t0,4)
    for i in range(4):
        y.append(splits[i].tolist())
        mi = len(y[i])//2
        y_mod.append(y[i][:mi])
        y_sti.append(y[i][mi:])

    plt.rc('font', size=12)

    fig, (ax1,ax2) = plt.subplots(1,2, figsize=(10, 6), sharey=True)
    for i in range(10):
        temp_mod = []
        temp_sti = []
        for j in range(4):
            temp_mod.append(y_mod[j][i])
            temp_sti.append(y_sti[j][i])
        ax1.plot(x,temp_mod)
        ax1.plot(x, avg_t0, 'tab:gray', linestyle='dashdot')
        ax2.plot(x,temp_sti)
        ax2.plot(x, avg_t0, 'tab:gray', linestyle='dashdot')

    ax1.set_title(r'$K_{ss}=K_{tt}=90, 65 \leq G_{R,fictitious} \leq 650$')
    ax2.set_title(r'$G_{R,fictitious}=637, 10 \leq K_{ss}=K_{tt} \leq 100$')

    ax1.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax2.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    for axs in (ax1,ax2):
        axs.label_outer()

    plt.savefig("C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\Mesh\\modVsStiffness.png")






# For comparing many many plots 
def compareStudy2(p2, expl):

    explanation = str(expl)

    x = ['5d', '10d', '15d', '20d']
    ref_t0 = [138.7, 180.4, 180.9, 159.4]
    avg_t0 = [131, 162.85, 163.15, 152.4]
    y_t0 = []
    y = []
    y_mod = []
    y_sti = []

    #p2 = r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\Mesh\\"

    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(p2+'\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t0.append((round(float(line[0]),2)))
            
    splits = np.array_split(y_t0,4)
    for i in range(4):
        y.append(splits[i].tolist())
        mi = len(y[i])//2
        y_mod.append(y[i][:mi])
        y_sti.append(y[i][mi:])

    plt.rc('font', size=18)

    fig, ax = plt.subplots(1, figsize=(10, 6), sharey=True)
    for i in range(20):
        temp_mod = []
        for j in range(4):
            temp_mod.append(y[j][i])
        ax.plot(x, temp_mod)
    ax.plot(x, avg_t0, 'tab:gray', linestyle='dashdot', label=r"$K_{avg,exp}$")

    ax.set_title(r'$T, \alpha=0^o, 100 \leq G_{R,fictitious} \leq 1000$')
    
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()

    plt.savefig(p2+"\\"+explanation+"_full.png")

# Comparing a graph to reference (Alisa) and original 
def generateGraphs3(path):

    x = ['5d', '10d', '15d', '20d']

    # LD, CH
    ref_c0 = [[124.2, 123.2, 120.8, 119.2], [108.2, 103.2, 102.8, 109.8]]
    ref_c90 = [[56.2, 68.6, 74.9, 83.7], [75.4, 69.2, 72.4, 83.4]]
    ref_t0 = [[138.7, 180.4, 180.9, 159.4], [123.3, 145.3, 145.4, 145.4]]
    ref_t90 = [[59, 87.70, 103.60, 102.70], [58.1, 78.6, 95.4, 91.8]]

    y_t0_ri = []
    y_t90_ri = []
    y_c0_ri = []
    y_c90_ri = []
    
    y_t0_fi = []
    y_t90_fi = []
    y_c0_fi = []
    y_c90_fi = []

    #p2 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\Mesh\\"

    # Reading the reduced integration files
    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(path+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_c0_ri.append((round(float(line[0]),2)))
        angle = 9
        c = open(path+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_c90_ri.append((round(float(line[0]),2)))
        angle = 0
        c = open(path+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t0_ri.append((round(float(line[0]),2)))
        angle = 9
        c = open(path+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t90_ri.append((round(float(line[0]),2)))

    # Reading the full integration files
    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\FullIntegrationM98K90"+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_c0_fi.append((round(float(line[0]),2)))
        angle = 9
        c = open(r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\FullIntegrationM98K90"+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_c90_fi.append((round(float(line[0]),2)))
        angle = 0
        c = open(r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\FullIntegrationM98K90"+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t0_fi.append((round(float(line[0]),2)))
        angle = 9
        c = open(r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\FullIntegrationM98K90"+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            y_t90_fi.append((round(float(line[0]),2)))

    plt.rc('font', size=12)

    fig, axs = plt.subplots(2,2,figsize=(10, 6), sharex=True, sharey=True)

    axs[0,0].plot(x, y_t0_ri, 'tab:green', label="G=450MPa")
    axs[0,0].plot(x, y_t0_fi, 'tab:blue', label="G=650MPa")
    axs[0,0].plot(x, ref_t0, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")  
    axs[0,0].set_title("(a) "+r'$Tension, \alpha=0^o$')

    axs[0,1].plot(x, y_c0_ri,'tab:red', label="G=450MPa")
    axs[0,1].plot(x, y_c0_fi, 'tab:blue', label="G=650MPa")
    axs[0,1].plot(x, ref_c0, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")  
    axs[0,1].set_title("(b) "+r'$Compression, \alpha=0^o$')

    axs[1,0].plot(x, y_t90_ri, 'tab:green', label="G=450MPa")
    axs[1,0].plot(x, y_t90_fi, 'tab:blue', label="G=650MPa")
    axs[1,0].plot(x, ref_t90, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")  
    axs[1,0].set_title("(c) "+r'$Tension, \alpha=90^o$')

    axs[1,1].plot(x, y_c90_ri,'tab:red', label="G=450MPa")
    axs[1,1].plot(x, y_c90_fi, 'tab:blue', label="G=650MPa")
    axs[1,1].plot(x, ref_c90, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")  
    axs[1,1].set_title("(d) "+r'$Compression, \alpha=90^o$')

    for ax in axs.flat:
        ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
        ax.label_outer()
        ax.legend()

    plt.savefig(path+"\\compOrg.png")

    plt.rc('font', size=18)

    fig2, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_t0_ri, 'tab:green', label="G=450MPa")
    ax.plot(x, y_t0_fi, 'tab:blue', label="G=650MPa")
    ax.plot(x, ref_t0, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")  
    ax.set_title(r'$Tension, \alpha=0^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\t0Org.png")

    fig3, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_t90_ri, 'tab:green', label="G=450MPa")
    ax.plot(x, y_t90_fi, 'tab:blue', label="G=650MPa")
    ax.plot(x, ref_t90, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")  
    ax.set_title(r'$Tension, \alpha=90^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\t90Org.png")

    fig4, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_c0_ri,'tab:red', label="G=450MPa")
    ax.plot(x, y_c0_fi, 'tab:blue', label="G=650MPa")
    ax.plot(x, ref_c0, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")
    ax.set_title(r'$Compression, \alpha=0^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\c0Org.png")

    fig5, ax = plt.subplots(1,figsize=(10, 6))
    ax.plot(x, y_c90_ri,'tab:red', label="G=450MPa")
    ax.plot(x, y_c90_fi, 'tab:blue', label="G=650MPa")
    ax.plot(x, ref_c90, 'tab:gray', linestyle='dotted',label=r"$K_{experimental}$")  
    ax.set_title(r'$Compression, \alpha=90^o$')
    ax.set(xlabel="Embedded length [mm]", ylabel="Stiffness [kN/mm]")
    ax.legend()
    plt.savefig(path+"\\c90Org.png")

path1 = r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\Full_Integration\K90G98"
path2 = r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\Reduced_Integration\K90G98"
p3 = r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\Full_Integration\ShearModulusStudy\WithG23"

# Basic tool for graphing for the lateral model
def graphLateral(filename, modelSpec, modifier, stiffness):
    displacement = []
    force = []
    p2 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\"
    f = open(p2+filename+'.rpt')
    for line in f: 
        line = line.split()
        if len(line) > 0:
            try:
                if float(line[0])!=0.0:
                    relative_displacement = abs(float(line[1])) - abs(float(line[2]))
                    displacement.append(relative_displacement)
                    actual_force = abs(float(line[3]))*56/1000
                    force.append(actual_force)
            except: pass
    f.close()
    stiff = []
    c = open(p2 + modelSpec +  '.csv', 'a', newline='')
    writer = csv.writer(c)   
    # Add results to file and add LD & CH to list
    for i in range(len(displacement)):
        stiff.append(force[i]/displacement[i])

    avgstiff = sum(stiff)/len(stiff)
    writer.writerow([avgstiff, modifier, stiffness])
    c.close()
    
def openLateral(filename):
    x_ax = []
    y_ax = []
    p2 = "C:\\Users\\Johannes\\Documents\\Masteroppgave\\Calibration\\"
    f = open(p2+filename+'.csv')
    for line in f: 
        line = line.split(',')
        y_ax.append(float(line[0]))
        x_ax.append(float(line[1]))

    """
    avgx = sum(x)/len(x)
    avgy = sum(y)/len(y)
    stiffness = avgy/avgx"""

    plt.rc('font', size=18)
    fig, ax = plt.subplots(1, figsize=(10,6))
    ax.set_title(r"Lateral loading, $\alpha=90^o$")
    ax.set(ylabel="Stiffness [kN/mm]", xlabel="Young's modulus [MPa]")
    ax.plot(x_ax, y_ax)
    plt.savefig(p2+"lateral90.png")

def spreadshit(path):
    # Average of Alisa LD and CH values
    avg_c0 = [116.2, 113.2, 111.8, 114.5]
    avg_c90 = [65.8, 68.9, 73.65, 83.55]
    avg_t0 = [131, 162.85, 163.15, 152.4]
    avg_t90 = [58.55, 83.15, 99.5, 97.25]

    # This is where "my" average stiffness values go 
    y_t0 = []
    y_t90 = []
    y_c0 = []
    y_c90 = []

    d = open(path + "test" +  '.csv', 'w', newline='')
    writer = csv.writer(d)
    writer.writerow(["$K_{num}$ [kN/mm]", "$K_{exp}$ [kN/mm]", "Error %"])

    # Read all .csv files in directory 
    for i in range(4):
        length = (i+1)*110
        angle = 0
        c = open(path+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_c90.append(0.5*(x1+x2))
        
        angle = 9
        c = open(path+'\\C.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_c0.append(0.5*(x1+x2))

        angle = 0
        c = open(path+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_t0.append(0.5*(x1+x2))

        angle = 9
        c = open(path+'\\T.'+str(angle)+'.'+str(length)+'.csv', 'r')
        reader = csv.reader(c)
        for line in reader:
            x1 = ((round(float(line[0]),2)))
            x2 = ((round(float(line[1]),2)))
            y_t90.append(0.5*(x1+x2))

    for i in range(len(y_t0)):
        x1 = round(y_t0[i], 2)
        x2 = round(avg_t0[i], 2)
        e = round(100*(x1-x2)/x1, 1)
        writer.writerow([x1, x2, str(e)+"%"])
    for i in range(len(y_t90)):
        x1 = round(y_t90[i], 2)
        x2 = round(avg_t90[i], 2)
        e = round(100*(x1-x2)/x1, 1)
        writer.writerow([x1, x2, str(e)+"%"])
    for i in range(len(y_c0)):
        x1 = round(y_c0[i], 2)
        x2 = round(avg_c0[i], 2)
        e = round(100*(x1-x2)/x1, 1)
        writer.writerow([x1, x2, str(e)+"%"])
    for i in range(len(y_c90)):
        x1 = round(y_c90[i], 2)
        x2 = round(avg_c90[i], 2)
        e = round(100*(x1-x2)/x1, 1)
        writer.writerow([x1, x2, str(e)+"%"])     
        

#generateGraphs(r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\Mesh\\", "K10M100") 
spreadshit(r"C:\Users\Johannes\Documents\Masteroppgave\Calibration\Full_Integration\K90M98\\")